%% plots IV for single level model analytical vs temperature broadened
clear
close all
clc

%%

savepath = 'D:\Luca\SURFdrive\Dissertation\Chap 1\';
%parameters used for the model
eps = 0.5;
gamma1 = 5e-3;
gamma2 = 5e-3;
Vmin = -2;
Vmax = 2;
V = Vmin:0.0001:Vmax;

%% Defines analytical function for the current

G0 = 7.7481e-05;%S
e = 1.60217662e-19;%C
h = 6.62607015e-34; %J s



%Imodel = @(e0,g1,g2,x) e.*2.*(e./h).* ((g1.*g2)./((g1+g2)/2)).* ...
%    (atan((e0+x./2)./((g1+g2)./2))-atan((e0-x./2)./((g1+g2)./2)));

Imodel = @(e0,g1,g2,x) 2.*(e./h).*4.*e.*((g1.*g2)./(g1+g2)).*...
    (atan((e0+x./2)./(g1+g2))-atan((e0-x./2)./(g1+g2)));


Ianalytical = Imodel(eps,gamma1,gamma2,V);
I293K = slModelbroadT2([eps gamma1 gamma2],V,293);

FNanalytical = log((abs(Ianalytical)./V.^2));
FN293K = log(abs(I293K)./V.^2);

%% calculates IVs for a temperature sweep
%revTvalues = 1./linspace(1,343,6);
revTvalues = 1./[4.15 77 194.7 293 343];
ITsweep = zeros(length(revTvalues),length(V));
for i = 1:length(revTvalues)
    ITsweep(i,:) = slModelbroadT2([eps gamma1 gamma2],V,1./revTvalues(i));
end

%% finds equivalent IV

%remove points at 0 bias
Vfitmin = -1.0;
Vfitmax = 1.0;
Vfit = V(V~=0 &(V>Vfitmin&V<Vfitmax));
Ifit = I293K(V~=0&(V>Vfitmin&V<Vfitmax));

opts  = optimoptions(@lsqcurvefit,'display','off','Algorithm','trust-region-reflective','MaxFunctionEvaluations',50000,'MaxIterations',15000,'OptimalityTolerance',1e-30,'FunctionTolerance',1e-26);
eqcoeff = lsqcurvefit(@BWmodelanalytical2,[0.5 0.01 0.01],Vfit,Ifit,[0 0 0],[2 1 1],opts);
%eqcoeff = lsqcurvefit(@BWmodelanalyticalLog2,[0.5 0.01 0.01],Vfit,log10(abs(Ifit)),[0 0 0],[2 1 1],opts);

Iequivalent = BWmodelanalytical2(eqcoeff,V);
FNequivalent = log((abs(Iequivalent)./V.^2));

%% Plot analytical model with lines at 2eps
F1 = figure('units','centimeters','position',[5 5 6.5 6],'paperposition',[0 0 6.5 6]);
set(gca,'ColorOrder',linspecer(3))
hold on
plot(V,Ianalytical,'linewidth',1)

plot(2*eps*ones(length(V),1),linspace(2*min(Ianalytical)*1e6,2*max(Ianalytical)*1e6,length(V)),'linewidth',1,'linestyle','--','color','k') %linie at 2eps
plot(-2*eps*ones(length(V),1),linspace(2*min(Ianalytical)*1e6,2*max(Ianalytical)*1e6,length(V)),'linewidth',1,'linestyle','--','color','k') %line at -seps
xlim([-0.2 0.2])

%legend({'analytical','293 K','equivalent'},'location','southeast')
xlabel('Bias Voltage (V)')
ylabel('Current (\muA)')
xlim([Vmin,Vmax])
ylim([1.25*min(Ianalytical)*1e6 1.25*max(Ianalytical)*1e6])
xticks(Vmin:1:Vmax)

setFigPropSmall(F1,gca)

exportgraphics(F1,[savepath 'BWmodel_analytical.pdf'],'contenttype','vector')
exportgraphics(F1,[savepath 'BWmodel_analytical.png'])
%close all

%% Plot a comparison between the 293K IV and a fit to it

F2 = figure('units','centimeters','position',[5 5 6.5 6],'paperposition',[0 0 6.5 6]);
set(gca,'ColorOrder',linspecer(2))
hold on
%plot(V,Ianalytical.*1e9,'linewidth',1)
%plot(V,Ianalytical2(eps,gamma1,gamma2,V))
plot(V,I293K.*1e6,'linewidth',1)
plot(V,Iequivalent.*1e6,'linewidth',1,'linestyle','--')

legend({'293 K','fitted analytical'},'location','southeast')
xlabel('Bias Voltage (V)')
ylabel('Current (\muA)')
xlim([Vfitmin Vfitmax])
xticks(Vmin:0.5:Vmax)


setFigPropSmall(F2,gca)
exportgraphics(F2,[savepath 'BWmodel_temperature_zoomed.pdf'],'contenttype','vector')
exportgraphics(F2,[savepath 'BWmodel_temperature_zoomed.png'])
%close all


%% Plot a comparison between the 293K IV and a fit to it, larger range

F6 = figure('units','centimeters','position',[5 5 6.5 6],'paperposition',[0 0 6.5 6]);
set(gca,'ColorOrder',linspecer(2))
hold on
%plot(V,Ianalytical.*1e9,'linewidth',1)
%plot(V,Ianalytical2(eps,gamma1,gamma2,V))
plot(V,I293K.*1e6,'linewidth',1)
plot(V,Iequivalent.*1e6,'linewidth',1,'linestyle','--')

legend({'293 K','fitted analytical'},'location','southeast')
xlabel('Bias Voltage (V)')
ylabel('Current (\muA)')
xlim([Vmin Vmax])
xticks(Vmin:1:Vmax)


setFigPropSmall(F6,gca)
exportgraphics(F6,[savepath 'BWmodel_temperature_fit.pdf'],'contenttype','vector')
exportgraphics(F6,[savepath 'BWmodel_temperature_fit.png'])
%close all

%% Plot Fowler-Nordheim 
% 
% F3 = figure('units','centimeters','position',[5 5 6.5 6],'paperposition',[0 0 6.5 6]);
% hold on
% plot(1./V,FNanalytical,'linewidth',1)
% %plot(V,Ianalytical2(eps,gamma1,gamma2,V))
% plot(1./V,FN293K,'linewidth',1)
% plot(1./V,FNequivalent,'linewidth',1)
% 
% legend({'analytical','290 K','equivalent'},'location','northeast')
% xlabel('1/V')
% ylabel('log(|I|/V^2)')
% xlim([-10 10])
%xticks(Vmin:0.2:Vmax)
% 
% 
% setFigPropSmall(F3,gca)
% exportgraphics(F3,[savepath 'BWmodel_temperature_FN.pdf'],'contenttype','vector')
% exportgraphics(F3,[savepath 'BWmodel_temperature_FN.png'])
% %close all

%% Plots finer temperature dependence
F4 = figure('units','centimeters','position',[5 5 6.5 6],'paperposition',[0 0 6.5 6]);
col = linspecer(length(revTvalues));
%set(gca,'ColorOrder',flip(hot(length(revTvalues)+round(0.5*length(revTvalues))),1))
%set(gca,'ColorOrder',cool(length(revTvalues)+round(0.5*length(revTvalues))))
%set(gca,'ColorOrder',jet(length(revTvalues)+0))
%set(gca,'ColorOrder',copper(length(revTvalues)+0))
%set(gca,'ColorOrder',winter(length(revTvalues)+0))
%set(gca,'ColorOrder',summer(length(revTvalues)+0))
set(gca,'ColorOrder',magma(length(revTvalues)+0))

%set(gca,'ColorOrder',linspecer(length(revTvalues)))

hold on

leg = cell(length(revTvalues),1);
for i = 1:length(revTvalues)
    plot(V,ITsweep(i,:).*1e6,'linewidth',1)%,'color',col(i,:))
    leg{i} = ['T = ' num2str(round(1./revTvalues(i))) ' K'];
end

plot(V(1:200:end),Ianalytical(1:200:end).*1e6,'x','color',col(1,:),'MarkerSize',4) %adds the analtical approx as scattered points
leg{length(revTvalues)+1} = 'Analytical';

xlim([2*eps-eps/2 2*eps+eps/2 ])

legend(leg,'location','southeast')
xlabel('Bias Voltage (V)')
ylabel('Current (\muA)')

setFigPropSmall(F4,gca)
exportgraphics(F4,[savepath 'BWmodel_temperature_dependence.pdf'],'contenttype','vector')
exportgraphics(F4,[savepath 'BWmodel_temperature_dependence.png'])


%% Plots zoomed out version of the previous plot
F5 = figure('units','centimeters','position',[5 5 6.5 6],'paperposition',[0 0 6.5 6]);
col = linspecer(length(revTvalues));
%set(gca,'ColorOrder',flip(hot(length(revTvalues)+round(0.5*length(revTvalues))),1))
%set(gca,'ColorOrder',cool(length(revTvalues)+round(0.5*length(revTvalues))))
%set(gca,'ColorOrder',jet(length(revTvalues)+0))
%set(gca,'ColorOrder',copper(length(revTvalues)+0))
%set(gca,'ColorOrder',winter(length(revTvalues)+0))
%set(gca,'ColorOrder',summer(length(revTvalues)+0))
set(gca,'ColorOrder',magma(length(revTvalues)+0))

%set(gca,'ColorOrder',linspecer(length(revTvalues)))

hold on

leg = cell(length(revTvalues),1);
for i = 1:length(revTvalues)
    plot(V,ITsweep(i,:).*1e6,'linewidth',1)%,'color',col(i,:))
    leg{i} = ['T = ' num2str(round(1./revTvalues(i))) ' K'];
end

%plot(V(1:200:end),Ianalytical(1:200:end).*1e9,'x','color',col(1,:),'MarkerSize',4) %adds the analtical approx as scattered points
%leg{length(revTvalues)+1} = 'Analytical';

%xlim([0 0.8])

legend(leg,'location','northwest')
xlabel('Bias Voltage (V)')
ylabel('Current (\muA)')
xticks(Vmin:1:Vmax)
%xlim([-0.2 0.2])
setFigPropSmall(F5,gca)
exportgraphics(F5,[savepath 'BWmodel_temperature_dependence_2.pdf'],'contenttype','vector')
exportgraphics(F5,[savepath 'BWmodel_temperature_dependence_2.png'])