% Plots examples of the histograms following Williams and Reuter model ()
% and a modification of it
clear
close all
clc
%
savepath = 'D:\Luca\SURFdrive\Dissertation\Chap 1\';

logGmin = -6;
logGmax = -2;

eps = 0.5;
deps = 0.01;
gamma = 10e-3;
dgammavalues = 1e-3:1e-3:3e-3;

G = 10.^(logGmin:0.001:logGmax);

%G = linspace(10.^logGmin, 10.^logGmax,1000000);

% plots histograms with WR model with different d
F1 = figure('units','centimeters','position',[5 5 6.5 6],'paperposition',[0 0 6.5 6]);
hold on
leg = cell(length(dgammavalues),1);
col = linspecer(length(dgammavalues));
for i =1:length(dgammavalues)
    ctmp = eps/dgammavalues(i);
    dtmp = gamma/dgammavalues(i);
    histoReutertmp= peakReuter([ctmp dtmp],G);
    leg{i} = ['\delta_\Gamma = ' num2str(dgammavalues(i)*1e3) ' meV'];
    plot(G,histoReutertmp,'color',col(i,:),'linewidth',1);
end
legend(leg)
ylim([0 1.1])
xlim([10.^logGmin 10.^logGmax])
set(gca,'xscale','log')
xticks([1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 1e0])
xlabel('Conductance (G_0)')
ylabel('Counts (a.u.)')
setFigPropSmall(F1,gca)
exportgraphics(F1,[savepath 'WRmodel_dgamma_effect.pdf'],'contenttype','vector')
exportgraphics(F1,[savepath 'WRmodel_dgamma_effect.png'])

% Plots a comparison between WR model and WR model with no approx

F2 = figure('units','centimeters','position',[5 5 6.5 6],'paperposition',[0 0 6.5 6]);
hold on
leg = cell(length(dgammavalues)+1,1);
col = linspecer(length(dgammavalues)+1);
for i =1:length(dgammavalues)
    
    %find equivalent parameters for log-normal distribution
    mu = log(gamma^2 ./ sqrt(gamma.^2 + dgammavalues(i).^2));
    sigma = sqrt(log(1+ dgammavalues(i).^2 ./ gamma.^2));
    %histoReutertmp= peakReuterlognormal([eps deps log(gamma) abs(log(gamma+dgammavalues(i))-log(gamma))],log10(G));
    histoReutertmp= peakReuterlognormal([eps deps mu sigma],log10(G));
    leg{i} = ['\delta_\Gamma = ' num2str(dgammavalues(i)*1e3) ' meV'];
    plot(G,histoReutertmp,'color',col(i,:),'linewidth',1);
end



%histoReutertmp= peakReuterlognormal([eps deps log(gamma) abs(log(gamma+dgammavalues(3))-log(gamma))],log10(G));
histoReutertmp= peakReuterlognormal([eps deps mu sigma],log10(G));
lognormalfit = fit(log10(G)',histoReutertmp','gauss1'); %fits a log-normal to the last calculated peak to get the right parameters
%plot(G,lognormalfit(log10(G)),'color',col(i+1,:),'linestyle','--');
area(G,lognormalfit(log10(G)),'FaceColor',col(i+1,:),'FaceAlpha',0.2,'EdgeColor','none')

leg{i+1} = 'log-normal peak';
legend(leg)
xticks([1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 1e0])

xlim([10.^logGmin 10.^logGmax])
set(gca,'xscale','log')
ylim([0 1.1])
xlabel('Conductance (G_0)')
ylabel('Counts (a.u.)')
setFigPropSmall(F2,gca)

exportgraphics(F2,[savepath 'WRmodel_lognorm.pdf'],'contenttype','vector')
exportgraphics(F2,[savepath 'WRmodel_lognorm.png'])
% histonoapprox = peakReuternormalNotnorm([eps deps gamma dgamma 1],log10(G));
% histonoapprox = peakReuterLogminassumptions([eps deps gamma dgamma 1],log10(G));
% histonoapprox = peakReuterlognormal([eps deps log(gamma) abs(log(gamma+dgamma)-log(gamma))],log10(G));
% histoReuter= peakReuter([c d],G);
% 
% plot(G,histoReuter)
% plot(G,histonoapprox./max(histonoapprox))
% set(gca,'xscale','log')
