function I = slModelbroadT2(coeff,V,Temp)
%Computes current at a voltage bias V using the single level model with
%trasnmission as a broadened lorenzian, at a temperature Temp (in K)

e = 1.60217662e-19;%C
h = 4.135667696e-15; %eV s
kb = 8.617333e-5; %eV/K
Ef = -5;%eV

eps = Ef-coeff(1);
gl  = coeff(2);
gr  = coeff(3);

f = @(E,mu,T) 1./(1+exp((E-mu)./(kb*T))); %Fermi distribution

T = @(E,e0,g1,g2) 4.*(g1.*g2)./((E-e0).^2 + (g1+g2).^2); %Lorentzian tranmsission function

i = @(E) T(E,eps,gl,gr) .* (f(E,Ef+(V)/2,Temp)-f(E,Ef-(V)/2,Temp)); %integrand to calculate the current

I = (2*e/h) * integral(i, -10,0,'ArrayValued',1);

end


